// Player.cpp: implementation of the CPlayer class.
//
//////////////////////////////////////////////////////////////////////


#include "stdafx.h"
#include "Othello.h"
#include "Player.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////
#include <SYS\TIMEB.H>
#include "Thebrain10.h"

CPlayer::CPlayer()
{
	tElapsed = 0;
	Brain = NULL;
}

CPlayer::~CPlayer()
{
	if (player == COMPUTER)
		delete Brain;
}
ePlayerType CPlayer::getPlayerType()
{
	return player;

}

void CPlayer::Set(ePlayerType type, int nSD, int nEGMT, nID playerA, nID playerB, nID playerEmpty)
{
	
	ID = playerA;
	player = type;

	if (type==HUMAN)
	{
		
		if (Brain) { delete Brain; Brain = NULL; }
		return;
	}
		
	if (!Brain)
	{
		Brain = new TheBrain10;
		ASSERT (!( Brain->is_mem_err() ));
	}

	nSearchDepth = nSD;
	nEndGameSearch = nEGMT;
	
	
	Brain->set_id(playerA, playerB, NONE);
	Brain->set_depth(nSD);	//set depth to be searched
	Brain->set_endgame_empty(nEGMT);	//set the start of endgame with d squares empty
	sName.Format ("Computer-%d", nSD);
}

void CPlayer::setName(CString str)
{
	sName = str;
}





nMoveLocation CPlayer::getComputerMove(OBoard& Board)
{	// there is a move available, then only this is called
	_timeb t1, t2;
	
	_ftime(&t1);
	nMoveLocation move = Brain->make_move(Board.getBoard());
	_ftime(&t2);

	ASSERT(Board.isLegal(ID, move));

	nNodesEvaluated = Brain->get_leaves_evaluated();
	tElapsed = (t2.time - t1.time)*1000 + t2.millitm-t1.millitm;

	return move;

}

long CPlayer::getElapsedTime()
{
	return tElapsed;

}

CString CPlayer::getName()
{
	return sName;

}

void CPlayer::Die()
{
	if (player == COMPUTER)
		delete Brain;

}

CPlayer::CPlayer(ePlayerType type, int nSD, int nEGMT)
{
	nSearchDepth = nSD;
	nEndGameSearch = nEGMT;
	player = type;

}

long CPlayer::getNodesEvaluated()
{
	return nNodesEvaluated;
}

nScore CPlayer::getCurrentScore()
{
	ASSERT(player == COMPUTER);
	return Brain->get_cur_score ();

}
